@@ -1,5 +1,6 @@
 import imghdr
 import os
+from dataclasses import dataclass
 
 from tldream import shared
 
@@ -19,7 +20,6 @@ from diffusers import UniPCMultistepScheduler, DDIMScheduler, DiffusionPipeline
 from loguru import logger
 from diffusers.utils import DIFFUSERS_CACHE
 import safetensors
-from pytorch_lightning import seed_everything
 from torch.hub import download_url_to_file
 
 from tldream.cldm.hack import enable_sliced_attention
@@ -64,6 +64,7 @@ def init_ckpt_pipe(model_path, device, torch_dtype, low_vram):
     cfg_path = current_dir / "cldm_v15.yaml"
     model = create_model(str(cfg_path), str(device)).cpu()
     model.low_vram = low_vram
+    model.device = device
 
     logger.info(f"Loading model from: {model_path}")
     model_state_dict = load_state_dict(model_path, location="cpu")
@@ -256,9 +257,20 @@ def HWC3(x):
         return y
 
 
+def seed_everything(seed):
+    random.seed(seed)
+    np.random.seed(seed)
+    torch.manual_seed(seed)
+    torch.cuda.manual_seed(seed)
+    torch.backends.cudnn.deterministic = True
+    torch.backends.cudnn.benchmark = False
+
+
 @torch.no_grad()
 def ckpt_process(
     model,
+    device,
+    torch_dtype,
     sampler: str,
     input_image: np.ndarray,
     prompt: str,
@@ -271,8 +283,6 @@ def ckpt_process(
     seed: int = -1,
     callback=None,
 ):
-    device = model.device
-    torch_dtype = model.dtype
     sampler = all_ckpt_samplers[sampler](model, device, torch_dtype)
     logger.info(f"Original image shape: {input_image.shape}")
     img = HWC3(input_image)
@@ -291,7 +301,7 @@ def ckpt_process(
     control = einops.rearrange(control, "b h w c -> b c h w").clone()
 
     if seed == -1:
-        seed = random.randint(0, 9999999999)
+        seed = random.randint(0, 2**32 - 1)
     seed_everything(seed)
 
     low_vram = model.low_vram
@@ -347,6 +357,8 @@ def ckpt_process(
 @torch.no_grad()
 def process(
     pipe,
+    device,
+    torch_dtype,
     sampler: str,
     input_image: np.ndarray,
     prompt: str,
@@ -363,6 +375,8 @@ def process(
     if not isinstance(pipe, DiffusionPipeline):
         return ckpt_process(
             pipe,
+            device,
+            torch_dtype,
             sampler,
             input_image,
             prompt,
